@@ -6,7 +6,7 @@ use warnings;
 
 our @ISA = qw();
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 
 # Preloaded methods go here.
@@ -168,11 +168,17 @@ sub delete_all {
 # @return \%Response
 #
 sub response {
- if ( $_[0]->{response}->is_success ) {
-  $_[0]->{json}->decode( $_[0]->{response}->decoded_content );
- } else {
-  { ErrorStatus => $_[0]->{response}->status_line };
+ my $res;
+ if ( $_[0]->{response} && $_[0]->{response}->is_success ) {
+  eval {
+   $res = $_[0]->{json}->decode( $_[0]->{response}->decoded_content );
+  };
+
+ } elsif ( $_[0]->{response} ) {
+  $res = { ErrorStatus => $_[0]->{response}->status_line || 'Erro ao conectar com o gateway de pagamentos.' };
  }
+
+ return $res || { ErrorStatus => 'Resposta inconforme do gateway de pagamentos.' };
 }
 
 #
@@ -525,7 +531,7 @@ Make a PUT request to Vindi API.
 
 =item endpoint
 
-URI PATH. Required.
+URI PATH. Required. No /vi prefix required.
 
 =over
 
@@ -543,7 +549,7 @@ Make a POST request to Vindi API. You must specify endpoint as first parameter,
 
 =item endpoint
 
-URL endpoint. Required.
+URL endpoint. Required. No /v1 required.
 
 =over
 
@@ -551,7 +557,7 @@ URL endpoint. Required.
 
 =item data
 
-A hash to be sent.
+A hash to be sent with the data. Plese check the examples above or the Vindi API docs.
 
 =over
 
@@ -559,6 +565,40 @@ A hash to be sent.
 
 =back
 
+=head2 Error handling
+
+Every request, no mather of what type, return a hashref. If this hashref has a key called ErrorStatus with ant true value
+in it, an error happened. You can print the ErrorStatus value to the user (this library is able to translate some errors to 
+a reasonable human/end user readable text). Or you can check the Vindi's own error object, which will be available on the
+"error" key.
+
+    my $customer = $vindi->post( 'customer', { name => '...', ... } )
+    if ( $customer->{ErrorStatus} ) {
+        print $customer->{ErrorStatus};
+        print Data::Dumper::Dumper( $customer->{error} );
+    }
+
+=over
+
+=item ErrorStatus
+
+Human friendly error message (whenever possible).
+
+=over
+
+=back
+
+=item error
+
+The error hashref as sent by the Vindi API.
+
+=over
+
+=back
+
+=back
+
+
 =head1 SEE ALSO
 
 Please check Vindi's full v1 API docs at http://www.vindi.com.br/ (you will need an API key to access this page).
